@@ -48,6 +48,9 @@
 #include "gpafilesignop.h"
 #include "gpafileverifyop.h"
 
+#include "icons.h"
+#include "helpmenu.h"
+
 
 /* Support for Gtk 2.8.  */
 
@@ -166,7 +169,7 @@ typedef gboolean (*sensitivity_func_t)(gpointer);
 /* Add widget to the list of sensitive widgets of editor.  */
 static void
 add_selection_sensitive_action (GpaClipboard *clipboard,
-                                GtkAction *action)
+                                GSimpleAction *action)
 {
   clipboard->selection_sensitive_actions
     = g_list_append (clipboard->selection_sensitive_actions, action);
@@ -189,7 +192,8 @@ has_selection (gpointer param)
 static void
 update_selection_sensitive_action (gpointer data, gpointer param)
 {
-  gtk_action_set_sensitive (GTK_ACTION (data), has_selection (param));
+//   gtk_action_set_sensitive (GTK_ACTION (data), has_selection (param));
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (data), has_selection (param));
 }
 
 
@@ -207,7 +211,7 @@ update_selection_sensitive_actions (GpaClipboard *clipboard)
 
 /* Add ACTION to the list of sensitive actions of CLIPBOARD.  */
 static void
-add_paste_sensitive_action (GpaClipboard *clipboard, GtkAction *action)
+add_paste_sensitive_action (GpaClipboard *clipboard, GSimpleAction *action)
 {
   clipboard->paste_sensitive_actions
     = g_list_append (clipboard->paste_sensitive_actions, action);
@@ -219,7 +223,8 @@ update_paste_sensitive_action (gpointer data, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
-  gtk_action_set_sensitive (GTK_ACTION (data), clipboard->paste_p);
+  // gtk_action_set_sensitive (GTK_ACTION (data), clipboard->paste_p);
+  g_simple_action_set_enabled (G_SIMPLE_ACTION (data), clipboard->paste_p);
 }
 
 
@@ -314,7 +319,7 @@ register_operation (GpaClipboard *clipboard, GpaFileOperation *op)
 
 /* Handle menu item "File/Clear".  */
 static void
-file_clear (GtkAction *action, gpointer param)
+file_clear (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -337,8 +342,8 @@ get_load_file_name (GtkWidget *parent, const gchar *title)
     {
       dialog = gtk_file_chooser_dialog_new
 	(title, GTK_WINDOW (parent), GTK_FILE_CHOOSER_ACTION_OPEN,
-	 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	 GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
+	 _("_Cancel"), GTK_RESPONSE_CANCEL,
+	 _("_Open"), GTK_RESPONSE_OK, NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
     }
   if (last_directory)
@@ -370,7 +375,7 @@ get_load_file_name (GtkWidget *parent, const gchar *title)
 
 /* Handle menu item "File/Open".  */
 static void
-file_open (GtkAction *action, gpointer param)
+file_open (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
   gchar *filename;
@@ -406,23 +411,25 @@ file_open (GtkAction *action, gpointer param)
       GtkWidget *hbox;
       GtkWidget *labelMessage;
       GtkWidget *pixmap;
+      GtkWidget *box;
       gint result;
       gchar *str;
 
       window = gtk_dialog_new_with_buttons
-	(_("GPA Message"), GTK_WINDOW (clipboard), GTK_DIALOG_MODAL,
-	 GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-	 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+        (_("GPA Message"), GTK_WINDOW (clipboard), GTK_DIALOG_MODAL,
+        _("_Open"), GTK_RESPONSE_OK,
+        _("_Cancel"), GTK_RESPONSE_CANCEL, NULL);
 
       gtk_container_set_border_width (GTK_CONTAINER (window), 5);
       gtk_dialog_set_default_response (GTK_DIALOG (window),
 				       GTK_RESPONSE_CANCEL);
 
-      hbox = gtk_hbox_new (FALSE, 0);
+      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
       gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-      gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (window)->vbox), hbox);
-      pixmap = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO,
-					 GTK_ICON_SIZE_DIALOG);
+      /*gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (window)->vbox), hbox);*/
+      box = gtk_dialog_get_content_area (GTK_DIALOG (window));
+      gtk_box_pack_start( GTK_BOX (box), hbox, TRUE, TRUE, 0);
+      pixmap = gtk_image_new_from_icon_name ("dialog-information", GTK_ICON_SIZE_DIALOG);
       gtk_box_pack_start (GTK_BOX (hbox), pixmap, TRUE, FALSE, 10);
 
       /* TRANSLATORS: The arguments are the filename, the integer size
@@ -492,8 +499,8 @@ get_save_file_name (GtkWidget *parent, const gchar *title)
     {
       dialog = gtk_file_chooser_dialog_new
 	(title, GTK_WINDOW (parent), GTK_FILE_CHOOSER_ACTION_SAVE,
-	 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-	 GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL);
+	 _("_Cancel"), GTK_RESPONSE_CANCEL,
+	 _("_Save"), GTK_RESPONSE_OK, NULL);
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
       gtk_file_chooser_set_do_overwrite_confirmation
 	(GTK_FILE_CHOOSER (dialog), TRUE);
@@ -534,7 +541,7 @@ get_save_file_name (GtkWidget *parent, const gchar *title)
 
 /* Handle menu item "File/Save As...".  */
 static void
-file_save_as (GtkAction *action, gpointer param)
+file_save_as (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
   gchar *filename;
@@ -574,7 +581,7 @@ file_save_as (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Verify".  */
 static void
-file_verify (GtkAction *action, gpointer param)
+file_verify (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = (GpaClipboard *) param;
   GpaFileVerifyOperation *op;
@@ -604,7 +611,7 @@ file_verify (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Sign".  */
 static void
-file_sign (GtkAction *action, gpointer param)
+file_sign (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = (GpaClipboard *) param;
   GpaFileSignOperation *op;
@@ -634,7 +641,7 @@ file_sign (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Encrypt".  */
 static void
-file_encrypt (GtkAction *action, gpointer param)
+file_encrypt (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = (GpaClipboard *) param;
   GpaFileEncryptOperation *op;
@@ -664,7 +671,7 @@ file_encrypt (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Decrypt".  */
 static void
-file_decrypt (GtkAction *action, gpointer param)
+file_decrypt (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = (GpaClipboard *) param;
   GpaFileDecryptOperation *op;
@@ -694,7 +701,15 @@ file_decrypt (GtkAction *action, gpointer param)
 
 /* Handle menu item "File/Close".  */
 static void
-file_close (GtkAction *action, gpointer param)
+file_close (GSimpleAction *simple, GVariant *parameter, gpointer param)
+{
+  GpaClipboard *clipboard = param;
+  gtk_widget_destroy (GTK_WIDGET (clipboard));
+}
+
+/* Handle menu item "File/Quit".  */
+static void
+file_quit (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
   gtk_widget_destroy (GTK_WIDGET (clipboard));
@@ -702,7 +717,7 @@ file_close (GtkAction *action, gpointer param)
 
 
 static void
-edit_cut (GtkAction *action, gpointer param)
+edit_cut (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -712,7 +727,7 @@ edit_cut (GtkAction *action, gpointer param)
 
 
 static void
-edit_copy (GtkAction *action, gpointer param)
+edit_copy (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -722,7 +737,7 @@ edit_copy (GtkAction *action, gpointer param)
 
 
 static void
-edit_paste (GtkAction *action, gpointer param)
+edit_paste (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -732,7 +747,7 @@ edit_paste (GtkAction *action, gpointer param)
 
 
 static void
-edit_delete (GtkAction *action, gpointer param)
+edit_delete (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -742,7 +757,7 @@ edit_delete (GtkAction *action, gpointer param)
 
 /* Handle menu item "Edit/Select All".  */
 static void
-edit_select_all (GtkAction *action, gpointer param)
+edit_select_all (GSimpleAction *simple, GVariant *parameter, gpointer param)
 {
   GpaClipboard *clipboard = param;
 
@@ -755,18 +770,45 @@ static void
 clipboard_action_new (GpaClipboard *clipboard,
 		      GtkWidget **menu, GtkWidget **toolbar)
 {
+
+  static const GActionEntry g_entries[] =
+  {
+    { "File", NULL },
+    { "Edit", NULL },
+
+    { "file_clear", file_clear },
+    { "file_open", file_open },
+    { "file_save_as", file_save_as },
+    { "file_sign", file_sign },
+    { "file_verify", file_verify },
+    { "file_encrypt", file_encrypt },
+    { "file_decrypt", file_decrypt },
+    { "file_close", file_close },
+    { "file_quit", file_quit },
+#if g
+    { "edit_undo", edit_undo },
+    { "edit_redo", edit_redo },
+#endif
+    { "edit_cut", edit_cut },
+    { "edit_copy", edit_copy },
+    { "edit_paste", edit_paste },
+    { "edit_delete", edit_delete },
+    { "edit_select_all", edit_select_all },
+  };
+
+  /*
   static const GtkActionEntry entries[] =
     {
-      /* Toplevel.  */
+      // Toplevel
       { "File", NULL, N_("_File"), NULL },
       { "Edit", NULL, N_("_Edit"), NULL },
 
-      /* File menu.  */
+      // File menu.
       { "FileClear", GTK_STOCK_CLEAR, NULL, NULL,
 	N_("Clear buffer"), G_CALLBACK (file_clear) },
-      { "FileOpen", GTK_STOCK_OPEN, NULL, NULL,
+      { "FileOpen", _("_Open"), NULL, NULL,
 	N_("Open a file"), G_CALLBACK (file_open) },
-      { "FileSaveAs", GTK_STOCK_SAVE_AS, NULL, NULL,
+      { "FileSaveAs", _("_Save")_AS, NULL, NULL,
 	N_("Save to a file"), G_CALLBACK (file_save_as) },
       { "FileSign", GPA_STOCK_SIGN, NULL, NULL,
 	N_("Sign buffer text"), G_CALLBACK (file_sign) },
@@ -776,14 +818,14 @@ clipboard_action_new (GpaClipboard *clipboard,
 	N_("Encrypt the buffer text"), G_CALLBACK (file_encrypt) },
       { "FileDecrypt", GPA_STOCK_DECRYPT, NULL, NULL,
 	N_("Decrypt the buffer text"), G_CALLBACK (file_decrypt) },
-      { "FileClose", GTK_STOCK_CLOSE, NULL, NULL,
+      { "FileClose", _("_Close"), NULL, NULL,
 	N_("Close the buffer"), G_CALLBACK (file_close) },
       { "FileQuit", GTK_STOCK_QUIT, NULL, NULL,
-	N_("Quit the program"), G_CALLBACK (gtk_main_quit) },
+	N_("Quit the program"), G_CALLBACK (g_application_quit) },
 
-      /* Edit menu.  */
+      // Edit menu.
 #if 0
-      /* FIXME: Not implemented yet.  */
+      // FIXME: Not implemented yet.
       { "EditUndo", GTK_STOCK_UNDO, NULL, NULL,
 	N_("Undo the last action"), G_CALLBACK (edit_undo) },
       { "EditRedo", GTK_STOCK_REDO, NULL, NULL,
@@ -800,7 +842,334 @@ clipboard_action_new (GpaClipboard *clipboard,
       { "EditSelectAll", GTK_STOCK_SELECT_ALL, NULL, "<control>A",
 	N_("Select the entire document"), G_CALLBACK (edit_select_all) }
     };
+    */
 
+  static const char *ui_string =
+    "<interface>"
+    "<menu id='menu'>"
+   "<submenu>"
+          "<attribute name='label' translatable='yes'>_File</attribute>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Clear</attribute>"
+            "<attribute name='action'>app.file_cleear</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Open</attribute>"
+            "<attribute name='action'>app.file_open</attribute>"
+          "</item>"
+          "<section>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Sign</attribute>"
+            "<attribute name='action'>app.file_sign</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Verify</attribute>"
+            "<attribute name='action'>app.file_verify</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Encrypt</attribute>"
+            "<attribute name='action'>app.file_encrypt</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Decrypt</attribute>"
+            "<attribute name='action'>app.file_decrypt</attribute>"
+          "</item>"
+          "</section>"
+          "<section>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Close</attribute>"
+            "<attribute name='action'>app.file_close</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Quit</attribute>"
+            "<attribute name='action'>app.file_quit</attribute>"
+          "</item>"
+          "</section>"
+        "</submenu>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>Edit</attribute>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Cut</attribute>"
+            "<attribute name='action'>app.edit_cut</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Copy</attribute>"
+            "<attribute name='action'>app.edit_copy</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Copy</attribute>"
+            "<attribute name='action'>app.edit_paste</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Delete</attribute>"
+            "<attribute name='action'>app.edit_delete</attribute>"
+          "</item>"
+          "<section>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Select All</attribute>"
+            "<attribute name='action'>app.edit_select_all</attribute>"
+          "</item>"
+          "</section>"
+          "<section>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Preferences</attribute>"
+            "<attribute name='action'>app.edit_preferences</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Backend Preferences</attribute>"
+            "<attribute name='action'>app.edit_backend_preferences</attribute>"
+          "</item>"
+          "</section>"
+        "</submenu>"
+        "<submenu>"
+          "<attribute name='label' translatable='yes'>Windows</attribute>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Keyring Manager</attribute>"
+            "<attribute name='action'>app.windows_keyring_editor</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>File Manager</attribute>"
+            "<attribute name='action'>app.windows_file_manager</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Clipboard</attribute>"
+            "<attribute name='action'>app.windows_clipboard</attribute>"
+          "</item>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>Card Manager</attribute>"
+            "<attribute name='action'>app.windows_card_manager</attribute>"
+          "</item>"
+      "</submenu>"
+      "<submenu>"
+          "<attribute name='label' translatable='yes'>Help</attribute>"
+          "<item>"
+            "<attribute name='label' translatable='yes'>About</attribute>"
+            "<attribute name='action'>app.help_about</attribute>"
+          "</item>"
+        "</submenu>"
+    "</menu>"
+    "<object id='toolbar' class='GtkToolbar'>"
+      "<property name='visible'>True</property>"
+      "<property name='can_focus'>False</property>"
+      "<property name='show_arrow'>False</property>"
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.file_clear</property>"
+          "<property name='icon_name'>edit-clear</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Clear buffer</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.edit_cut</property>"
+          "<property name='icon_name'>edit-cut</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Cut the selection</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.edit_copy</property>"
+          "<property name='icon_name'>edit-copy</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Copy the selection</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.edit_paste</property>"
+          "<property name='icon_name'>edit-paste</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Paste the clipboard</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.file_sign</property>"
+          "<property name='icon-name'>sign</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Sign buffer text</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton' id='brief_test'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='icon-name'>verify</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='action-name'>app.file_verify</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Check signatures of buffer text</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon-name'>encrypt</property>"
+          "<property name='action-name'>app.file_encrypt</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Encrypt the buffer text</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon-name'>decrypt</property>"
+          "<property name='action-name'>app.file_decrypt</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Decrypt the buffer text</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon_name'>preferences-desktop</property>"
+          "<property name='action-name'>app.edit_preferences</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Configure the application</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkSeparatorToolItem'>"
+        "</object>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon-name'>keyring</property>"
+          "<property name='action-name'>app.windows_keyring_editor</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the keyring editor</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='label' translatable='yes'>__glade_unnamed_10</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon-name'>folder</property>"
+          "<property name='action-name'>app.windows_file_manager</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the file manager</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+#ifdef ENABLE_CARD_MANAGER
+      "<child>"
+        "<object class='GtkToolButton'>"
+          "<property name='visible'>True</property>"
+          "<property name='can_focus'>False</property>"
+          "<property name='label' translatable='yes'>__glade_unnamed_10</property>"
+          "<property name='use_underline'>True</property>"
+          "<property name='icon-name'>smartcard</property>"
+          "<property name='action-name'>app.windows_card_manager</property>"
+          "<property name='has_tooltip'>true</property>"
+          "<property name='tooltip-text'>Open the card manager</property>"
+        "</object>"
+        "<packing>"
+          "<property name='expand'>False</property>"
+          "<property name='homogeneous'>True</property>"
+        "</packing>"
+      "</child>"
+#endif
+    "</object>"
+    "</interface>";
+
+/*
   static const char *ui_description =
     "<ui>"
     "  <menubar name='MainMenu'>"
@@ -818,7 +1187,7 @@ clipboard_action_new (GpaClipboard *clipboard,
     "    </menu>"
     "    <menu action='Edit'>"
 #if 0
-    /* Not implemented yet.  */
+    // Not implemented yet.
     "      <menuitem action='EditUndo'/>"
     "      <menuitem action='EditRedo'/>"
     "      <separator/>"
@@ -851,8 +1220,8 @@ clipboard_action_new (GpaClipboard *clipboard,
     "  <toolbar name='ToolBar'>"
     "    <toolitem action='FileClear'/>"
 #if 0
-    /* Disabled because the toolbar arrow mode doesn't work, and the
-       toolbar takes up too much space otherwise.  */
+    // Disabled because the toolbar arrow mode doesn't work, and the
+    // toolbar takes up too much space otherwise.
     "    <toolitem action='FileOpen'/>"
     "    <toolitem action='FileSaveAs'/>"
 #endif
@@ -878,7 +1247,9 @@ clipboard_action_new (GpaClipboard *clipboard,
 #endif
     "  </toolbar>"
     "</ui>";
+    */
 
+#ifdef OLD_MENU
   GtkAccelGroup *accel_group;
   GtkActionGroup *action_group;
   GtkAction *action;
@@ -935,6 +1306,89 @@ clipboard_action_new (GpaClipboard *clipboard,
   *menu = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
   *toolbar = gtk_ui_manager_get_widget (ui_manager, "/ToolBar");
   gpa_toolbar_set_homogeneous (GTK_TOOLBAR (*toolbar), FALSE);
+#else
+
+  GError *err = NULL;
+  GtkBuilder *gtk_builder;
+  GMenuModel *menu_bar_model;
+  GObject *grid;
+  GtkCssProvider *css_provider;
+  GdkDisplay *display;
+  GdkScreen *screen;
+  GtkStyleContext *style_context;
+  GtkApplication *gpa_app;
+  GSimpleAction *action;
+
+  gtk_builder = gtk_builder_new_from_string (icons_string, -1);
+
+  if (gtk_builder_add_from_string( gtk_builder, ui_string , -1, &err) == 0) {
+    printf("ERROR: %s \n", err->message);
+  }
+
+  menu_bar_model = G_MENU_MODEL (gtk_builder_get_object (GTK_BUILDER (gtk_builder), "menu"));
+  *menu = gtk_menu_bar_new_from_model (menu_bar_model);
+
+  grid = gtk_builder_get_object (GTK_BUILDER (gtk_builder), "toolbar");
+
+  css_provider = gtk_css_provider_new();
+  display = gdk_display_get_default();
+  screen = gdk_display_get_default_screen (display);
+  gtk_style_context_add_provider_for_screen (screen, GTK_STYLE_PROVIDER(css_provider), GTK_STYLE_PROVIDER_PRIORITY_USER);
+
+  gtk_css_provider_load_from_data(css_provider,
+                                        "#toolbar {\n"
+                                        //" padding-left: 55px;\n"
+                                        // " padding-right: 5px;\n"
+                                        // " border-radius: 3px;\n"
+                                        "}\n", -1, NULL);
+
+
+  style_context = gtk_widget_get_style_context (GTK_WIDGET (grid));
+
+  *toolbar = GTK_WIDGET (grid);
+
+  // We must set the name to the toolbar for css to recognize it
+  gtk_widget_set_name(*toolbar, "toolbar");
+
+  gtk_style_context_add_class (style_context, "toolbar");
+
+
+  gpa_app = get_gpa_application ();
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_windows_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_windows_menu_g_action_entries),
+                                    clipboard);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    g_entries,
+                                    G_N_ELEMENTS (g_entries),
+                                    clipboard);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_help_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_help_menu_g_action_entries),
+                                    clipboard);
+
+  g_action_map_add_action_entries (G_ACTION_MAP (gpa_app),
+                                    gpa_preferences_menu_g_action_entries,
+                                    G_N_ELEMENTS (gpa_preferences_menu_g_action_entries),
+                                    clipboard);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "edit_cut");
+  add_selection_sensitive_action (clipboard, action);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "edit_copy");
+  add_selection_sensitive_action (clipboard, action);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "edit_delete");
+  add_selection_sensitive_action (clipboard, action);
+
+  action = (GSimpleAction*)g_action_map_lookup_action (G_ACTION_MAP (gpa_app), "edit_paste");
+  // Initialized later
+  add_paste_sensitive_action (clipboard, action);
+
+#endif
 }
 
 
@@ -1025,7 +1479,7 @@ gpa_clipboard_constructor (GType type,
   gtk_widget_realize (GTK_WIDGET (clipboard));
 
   /* Use a vbox to show the menu, toolbar and the text container.  */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
   /* We need to create the text_buffer before we create the menus and
      the toolbar, because of widget sensitivity issues, which depend
@@ -1038,11 +1492,11 @@ gpa_clipboard_constructor (GType type,
   gtk_box_pack_start (GTK_BOX (vbox), toolbar, FALSE, TRUE, 0);
 
   /* Add a fancy label that tells us: This is the clipboard.  */
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 5);
 
   /* FIXME: Need better icon.  */
-  icon = gtk_image_new_from_stock (GTK_STOCK_PASTE, GTK_ICON_SIZE_DND);
+  icon = gtk_image_new_from_icon_name ("edit-paste", GTK_ICON_SIZE_DND);
   gtk_box_pack_start (GTK_BOX (hbox), icon, FALSE, TRUE, 0);
 
   label = gtk_label_new (NULL);
@@ -1051,11 +1505,11 @@ gpa_clipboard_constructor (GType type,
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 10);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
-
+  gtk_widget_set_halign (GTK_WIDGET (label), GTK_ALIGN_START);
+  gtk_widget_set_valign (GTK_WIDGET (label), GTK_ALIGN_CENTER);
 
   /* Third a text entry.  */
-  text_box = gtk_hbox_new (TRUE, 0);
+  text_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   align = gtk_alignment_new (0.5, 0.5, 1, 1);
   gtk_alignment_get_padding (GTK_ALIGNMENT (align),
 			     &pt, &pb, &pl, &pr);
